# MML Tag plugin

This plugin provides some additional task tags, ready to be imported.

# Install

```commandline
pip install mml-tags
```

# Usage

Type `mml-tags` for an overview on available tags and more details.